//  Diffusion Client Library for iOS, OS X and tvOS
//
//  Copyright (c) 2015 Push Technology Ltd., All Rights Reserved.
//
//  Use is subject to license terms.
//
//  NOTICE: All information contained herein is, and remains the
//  property of Push Technology. The intellectual and technical
//  concepts contained herein are proprietary to Push Technology and
//  may be covered by U.S. and Foreign Patents, patents in process, and
//  are protected by trade secret or copyright law.

@import Foundation;
#import <Diffusion/PTDiffusionFeature.h>

@class PTDiffusionCredentials;

NS_ASSUME_NONNULL_BEGIN

/**
 @brief The Security feature provides a client session with the ability to change
 the associated principal.

 The Security feature for a session can be obtained from the session's
 `security` property.

 @see PTDiffusionSession
 
 @since 5.6
 */
@interface PTDiffusionSecurityFeature : PTDiffusionFeature

/**
 Change the security principal associated with the current session.
 
 If authentication fails, the current principal will remain valid.

 @param principal The new principal name.

 @param credentials The credentials authenticating the new principal.

 @param completionHandler Block to be called asynchronously on success or failure.
 If the operation was successful, the `error` argument passed to the block will be `nil`.
 The completion handler will be called asynchronously on the main dispatch queue.

 @exception NSInvalidArgumentException Raised if the completionHandler argument is `nil`.
 
 @since 5.6
 */
-(void)changePrincipal:(nullable NSString *)principal
           credentials:(nullable PTDiffusionCredentials *)credentials
     completionHandler:(void (^)(NSError * _Nullable error))completionHandler;

@end

NS_ASSUME_NONNULL_END
